@@ -1,9 +1,11 @@
 """BleBox light entities tests."""
 import json
 
-from .conftest import DefaultBoxTest, jmerge, CommonEntity
+from .conftest import CommonEntity, DefaultBoxTest, future_date, jmerge
 
-from blebox_uniapi.error import UnsupportedBoxResponse, BadOnValueError
+from blebox_uniapi.box_types import get_latest_api_level
+from blebox_uniapi.error import BadOnValueError, UnsupportedBoxVersion
+from blebox_uniapi.light import Light
 
 # TODO: remove
 import colorsys
@@ -14,9 +16,31 @@ import pytest
 ATTR_BRIGHTNESS = "brightness"
 ATTR_HS_COLOR = "ATTR_HS_COLOR"
 ATTR_WHITE_VALUE = "ATTR_WHITE_VALUE"
+ATTR_RGB_COLOR = "rgb_color"
+ATTR_RGBW_COLOR = "rgbw_color"
+ATTR_EFFECT = "effect"
+ATTR_COLOR_TEMP = "color_temp"
+ATTR_RGBWW_COLOR = "rgbww_color"
 SUPPORT_BRIGHTNESS = 1
 SUPPORT_COLOR = 2
 SUPPORT_WHITE_VALUE = 4
+COLOR_MODE_BRIGHTNESS = "brightness"
+COLOR_MODE_COLOR_TEMP = "color_temp"
+COLOR_MODE_ONOFF = "onoff"
+COLOR_MODE_RGB = "rgb"
+COLOR_MODE_RGBW = "rgbw"
+COLOR_MODE_RGBWW = "rgbww"
+
+COLOR_MODE_MAP = {
+    1: COLOR_MODE_RGBW,
+    2: COLOR_MODE_RGB,
+    3: COLOR_MODE_BRIGHTNESS,
+    4: COLOR_MODE_RGBW,
+    # RGB and Brightness 2 and 3 implementation difference, if W hex is not null only this or RGB + Brightness separated with mask
+    5: COLOR_MODE_COLOR_TEMP,
+    6: COLOR_MODE_COLOR_TEMP,  # two instances
+    7: COLOR_MODE_RGBWW,
+}
 
 # NOTE: copied from Home Assistant color util module
 
@@ -24,7 +48,7 @@ SUPPORT_WHITE_VALUE = 4
 def rgb_hex_to_rgb_list(hex_string: str):
     """Return an RGB color value list from a hex color string."""
     return [
-        int(hex_string[i: i + len(hex_string) // 3], 16)
+        int(hex_string[i : i + len(hex_string) // 3], 16)
         for i in range(0, len(hex_string), len(hex_string) // 3)
     ]
 
@@ -70,61 +94,105 @@ class BleBoxLightEntity(CommonEntity):
     """Representation of BleBox lights."""
 
     @property
-    def supported_features(self):
-        """Return supported features."""
-        white = SUPPORT_WHITE_VALUE if self._feature.supports_white else 0
-        color = SUPPORT_COLOR if self._feature.supports_color else 0
-        brightness = SUPPORT_BRIGHTNESS if self._feature.supports_brightness else 0
-        return white | color | brightness
-
-    @property
-    def is_on(self):
+    def is_on(self) -> bool:
         """Return if light is on."""
         return self._feature.is_on
 
     @property
     def brightness(self):
-        """Return the name."""
+        """Return the brightness."""
         return self._feature.brightness
 
     @property
-    def white_value(self):
-        """Return the white value."""
-        return self._feature.white_value
+    def color_temp(self):
+        """Return color temperature."""
+        return self._feature.color_temp
 
     @property
-    def hs_color(self):
-        """Return the hue and saturation."""
-        rgbw_hex = self._feature.rgbw_hex
-        if rgbw_hex is None:
-            return None
+    def color_mode(self):
+        """Return the color mode. Set values to _attr_ibutes if needed."""
+        color_mode_tmp = COLOR_MODE_MAP.get(self._feature.color_mode, COLOR_MODE_ONOFF)
+        if color_mode_tmp == COLOR_MODE_COLOR_TEMP:
+            self._attr_min_mireds = 1
+            self._attr_max_mireds = 255
 
-        r, g, b, x = rgb_hex_to_rgb_list(rgbw_hex)
-        return color_RGB_to_hs(r, g, b)
+        return color_mode_tmp
+
+    @property
+    def effect_list(self):
+        """Return the list of supported effects."""
+        return self._feature.effect_list
+
+    @property
+    def effect(self):
+        """Return the current effect."""
+        return self._feature.effect
+
+    @property
+    def rgb_color(self):
+        """Return value for rgb."""
+        if (rgb_hex := self._feature.rgb_hex) is None:
+            return None
+        return tuple(
+            self._feature.normalise_elements_of_rgb(
+                self._feature.rgb_hex_to_rgb_list(rgb_hex)[0:3]
+            )
+        )
+
+    @property
+    def rgbw_color(self):
+        """Return the hue and saturation."""
+        if (rgbw_hex := self._feature.rgbw_hex) is None:
+            return None
+        return tuple(self._feature.rgb_hex_to_rgb_list(rgbw_hex)[0:4])
+
+    @property
+    def rgbww_color(self):
+        """Return value for rgbww."""
+        if (rgbww_hex := self._feature.rgbww_hex) is None:
+            return None
+        return tuple(self._feature.rgb_hex_to_rgb_list(rgbww_hex))
 
     async def async_turn_on(self, **kwargs):
         """Turn the light on."""
-
-        white = kwargs.get(ATTR_WHITE_VALUE, None)
-        hs_color = kwargs.get(ATTR_HS_COLOR, None)
-        brightness = kwargs.get(ATTR_BRIGHTNESS, None)
-
+        print("async_turn_on:", kwargs)
+        rgbw = kwargs.get(ATTR_RGBW_COLOR)
+        brightness = kwargs.get(ATTR_BRIGHTNESS)
+        effect = kwargs.get(ATTR_EFFECT)
+        color_temp = kwargs.get(ATTR_COLOR_TEMP)
+        rgbww = kwargs.get(ATTR_RGBWW_COLOR)
         feature = self._feature
         value = feature.sensible_on_value
+        rgb = kwargs.get(ATTR_RGB_COLOR)
+
+        if rgbw is not None:
+            value = list(rgbw)
+        if color_temp is not None:
+            value = feature.return_color_temp_with_brightness(
+                int(color_temp), self.brightness
+            )
+
+        if rgbww is not None:
+            value = list(rgbww)
+
+        if rgb is not None:
+            if self.color_mode == COLOR_MODE_RGB and brightness is None:
+                brightness = self.brightness
+            value = list(rgb)
 
         if brightness is not None:
-            value = feature.apply_brightness(value, brightness)
+            if self.color_mode == ATTR_COLOR_TEMP:
+                value = feature.return_color_temp_with_brightness(
+                    self.color_temp, brightness
+                )
+            else:
+                value = feature.apply_brightness(value, brightness)
 
-        if white is not None:
-            value = feature.apply_white(value, white)
-
-        # TODO: set via RGB
-        if hs_color is not None:
-            raw_rgb = color_rgb_to_hex(*color_hs_to_RGB(*hs_color))
-            value = feature.apply_color(value, raw_rgb)
-
-        # TODO: test for BadOnValueError case
-        await self._feature.async_on(value)
+        if effect is not None:
+            effect_value = self.effect_list.index(effect)
+            await self._feature.async_api_command("effect", effect_value)
+        else:
+            await self._feature.async_on(value)
 
     async def async_turn_off(self, **kwargs):
         """Turn the light off."""
@@ -174,11 +242,10 @@ class TestDimmer(DefaultBoxTest):
         {{ "device": {{ "apiLevel": {apiLevel} }} }}
         """
 
-    DEVICE_INFO_FUTURE = jmerge(DEVICE_INFO, patch_version(20170930))
-    DEVICE_INFO_LATEST = jmerge(DEVICE_INFO, patch_version(20170829))
-    DEVICE_INFO_OUTDATED = jmerge(DEVICE_INFO, patch_version(20170829))
-
-    DEVICE_INFO_MINIMUM = jmerge(DEVICE_INFO, patch_version(20170829))
+    DEVICE_INFO_FUTURE = jmerge(DEVICE_INFO, patch_version(future_date()))
+    DEVICE_INFO_LATEST = jmerge(
+        DEVICE_INFO, patch_version(get_latest_api_level("dimmerBox"))
+    )
     DEVICE_INFO_UNSUPPORTED = jmerge(DEVICE_INFO, patch_version(20170828))
 
     DEVICE_INFO_UNSPECIFIED_API = json.loads(
@@ -237,7 +304,7 @@ class TestDimmer(DefaultBoxTest):
         """
 
     STATE_OFF = jmerge(STATE_DEFAULT, patch_state(0, 0))
-    STATE_ON_DEFAULT = jmerge(STATE_DEFAULT, patch_state(238, 254))
+    STATE_ON_DEFAULT = jmerge(STATE_DEFAULT, patch_state(238, 255))
     STATE_ON_BRIGHT = jmerge(STATE_DEFAULT, patch_state(201, 202))
 
     async def test_init(self, aioclient_mock):
@@ -248,7 +315,7 @@ class TestDimmer(DefaultBoxTest):
         assert entity.name == "My dimmer (dimmerBox#brightness)"
         assert entity.unique_id == "BleBox-dimmerBox-1afe34e750b8-brightness"
 
-        assert entity.supported_features & SUPPORT_BRIGHTNESS
+        # assert entity.supported_features & SUPPORT_BRIGHTNESS
         assert entity.brightness is None
 
         assert entity.is_on is None
@@ -294,7 +361,7 @@ class TestDimmer(DefaultBoxTest):
 
         assert entity.is_on is True
         # TODO: is max brightness a good default?
-        assert entity.brightness == 254
+        assert entity.brightness == 255
 
     async def test_on_with_brightness(self, aioclient_mock):
         """Test light on with a brightness value."""
@@ -331,18 +398,20 @@ class TestWLightBoxS(DefaultBoxTest):
     DEVCLASS = "lights"
     ENTITY_CLASS = BleBoxLightEntity
 
-    DEV_INFO_PATH = "api/light/state"
+    DEVICE_EXTENDED_INFO_PATH = "/api/rgbw/extended/state"
+    DEV_INFO_PATH = "api/rgbw/state"
     DEVICE_INFO = json.loads(
         """
     {
         "device": {
             "deviceName": "My wLightBoxS",
-            "type": "wLightBoxS",
+            "type": "wLightBox",
+            "product":"wLightBoxS",
             "fv": "0.924",
             "hv": "0.1",
             "universe": 0,
             "id": "1afe34e750b8",
-            "apiLevel": 20180718,
+            "apiLevel": 20200229,
             "ip": "192.168.9.13",
             "availableFv": null
         }
@@ -361,7 +430,20 @@ class TestWLightBoxS(DefaultBoxTest):
             "apiLevel": "20200229",
             "id": "ce50e32d2707",
             "ip": "192.168.1.25",
-            "availableFv": None
+            "availableFv": None,
+        }
+    }
+
+    DEVICE_EXTENDED_INFO = {
+        "rgbw": {
+            "desiredColor": "f5",
+            "currentColor": "f5",
+            "lastOnColor": "f5",
+            "durationsMs": {"colorFade": 1000, "effectFade": 1000, "effectStep": 1000},
+            "effectID": 0,
+            "colorMode": 3,
+            "favColors": {"0": "ff", "1": "00", "2": "c0", "3": "40", "4": "00"},
+            "effectsNames": {"0": "NONE", "1": "FADE", "2": "Stroboskop", "3": "BELL"},
         }
     }
 
@@ -371,11 +453,10 @@ class TestWLightBoxS(DefaultBoxTest):
         {{ "device": {{ "apiLevel": {apiLevel} }} }}
         """
 
-    DEVICE_INFO_FUTURE = jmerge(DEVICE_INFO, patch_version(20180719))
-    DEVICE_INFO_LATEST = jmerge(DEVICE_INFO, patch_version(20180718))
-    DEVICE_INFO_OUTDATED = jmerge(DEVICE_INFO, patch_version(20180718))
-
-    DEVICE_INFO_MINIMUM = jmerge(DEVICE_INFO, patch_version(20180718))
+    DEVICE_INFO_FUTURE = jmerge(DEVICE_INFO, patch_version(future_date()))
+    DEVICE_INFO_LATEST = jmerge(
+        DEVICE_INFO, patch_version(get_latest_api_level("wLightBoxS"))
+    )
     DEVICE_INFO_UNSUPPORTED = jmerge(DEVICE_INFO, patch_version(20180717))
 
     DEVICE_INFO_UNSPECIFIED_API = json.loads(
@@ -395,10 +476,11 @@ class TestWLightBoxS(DefaultBoxTest):
             "apSSID": "wLightBoxS-ap",
             "apPasswd": ""
         },
-        "light": {
+        "rgbw": {
             "desiredColor": "e3",
             "currentColor": "df",
-            "fadeSpeed": 255
+            "fadeSpeed": 255,
+            "effectID": 0
         }
     }
     """
@@ -407,10 +489,12 @@ class TestWLightBoxS(DefaultBoxTest):
     STATE_ON = json.loads(
         """
         {
-            "light": {
+            "rgbw": {
                 "desiredColor": "ab",
                 "currentColor": "cd",
-                "fadeSpeed": 255
+                "fadeSpeed": 255,
+                "effectID": 0,
+                "colorMode": 3
             }
         }
     """
@@ -419,10 +503,11 @@ class TestWLightBoxS(DefaultBoxTest):
     STATE_FULL_ON = json.loads(
         """
         {
-            "light": {
+            "rgbw": {
                 "desiredColor": "ff",
                 "currentColor": "ce",
-                "fadeSpeed": 255
+                "fadeSpeed": 255,
+                "effectID": 0
             }
         }
     """
@@ -431,10 +516,11 @@ class TestWLightBoxS(DefaultBoxTest):
     STATE_OFF = json.loads(
         """
         {
-            "light": {
+            "rgbw": {
                 "desiredColor": "00",
                 "currentColor": "00",
-                "fadeSpeed": 255
+                "fadeSpeed": 255,
+                "effectID": 0
             }
         }
     """
@@ -447,10 +533,10 @@ class TestWLightBoxS(DefaultBoxTest):
         await self.allow_get_info(aioclient_mock)
         entity = (await self.async_entities(aioclient_mock))[0]
 
-        assert entity.name == "My wLightBoxS (wLightBoxS#brightness)"
-        assert entity.unique_id == "BleBox-wLightBoxS-1afe34e750b8-brightness"
-
-        assert entity.supported_features & SUPPORT_BRIGHTNESS
+        assert entity.name == "My wLightBoxS (wLightBoxS#brightness_mono1)"
+        assert entity.unique_id == "BleBox-wLightBoxS-1afe34e750b8-brightness_mono1"
+        print(entity.color_mode)
+        # assert entity.color_mode & SUPPORT_BRIGHTNESS this assertion needs to be refactored, after extended state will be mockable
         assert entity.brightness is None
 
         assert entity.is_on is None
@@ -477,25 +563,28 @@ class TestWLightBoxS(DefaultBoxTest):
         """Test light updating."""
 
         entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
-
+        print("TU:", entity.color_mode)
         assert entity.brightness == 0xAB
         assert entity.is_on is True
 
     async def allow_set_brightness(self, code, aioclient_mock, value, response):
         """Set up mock for HTTP POST simulating color change."""
-
-        raw = "{:02X}".format(value)
+        print("allow_set_brightness", response)
+        raw = "{:02x}".format(value)
         await self.allow_post(
             code,
             aioclient_mock,
-            "/api/light/set",
-            json.dumps({"light": {"desiredColor": raw}}),
+            "/api/rgbw/set",
+            json.dumps(
+                {"rgbw": {"desiredColor": raw + "------"}}
+            ),  # simulating mask for color mod 3
             response,
         )
 
     async def test_on(self, aioclient_mock):
         """Test light on."""
         entity = await self.updated(aioclient_mock, self.STATE_OFF)
+        print("Ent: ", entity)
         assert entity.is_on is False
 
         async def turn_on():
@@ -550,6 +639,7 @@ class TestWLightBox(DefaultBoxTest):
     DEVCLASS = "lights"
     ENTITY_CLASS = BleBoxLightEntity
 
+    DEVICE_EXTENDED_INFO_PATH = "/api/rgbw/extended/state"
     # TODO: rename everywhere (STATE_PATH)
     DEV_INFO_PATH = "api/rgbw/state"
 
@@ -567,6 +657,103 @@ class TestWLightBox(DefaultBoxTest):
     }
     """
     )
+    DEVICE_EXTENDED_INFO = {
+        "rgbw": {
+            "colorMode": 4,
+            "effectID": 0,
+            "desiredColor": "fa00203A",
+            "currentColor": "ff00302F",
+            "lastOnColor": "f1e2d3e4",
+            "durationsMs": {"colorFade": 1000, "effectFade": 1500, "effectStep": 2000},
+            "favColors": {"0": "ff", "1": "00", "2": "c0", "3": "40", "4": "00"},
+            "effectsNames": {"0": "NONE", "1": "FADE", "2": "Stroboskop", "3": "BELL"},
+        }
+    }
+    DEVICE_EXTENDED_INFO_COLORMODE_1 = {
+        "rgbw": {
+            "colorMode": 1,
+            "effectID": 0,
+            "desiredColor": "fa",
+            "currentColor": "ff",
+            "lastOnColor": "ff",
+            "durationsMs": {"colorFade": 1000, "effectFade": 1500, "effectStep": 2000},
+            "favColors": {"0": "ff", "1": "00", "2": "c0", "3": "40", "4": "00"},
+            "effectsNames": {"0": "NONE", "1": "FADE", "2": "Stroboskop", "3": "BELL"},
+        }
+    }
+    DEVICE_EXTENDED_INFO_COLORMODE_2 = {
+        "rgbw": {
+            "colorMode": 2,
+            "effectID": 0,
+            "desiredColor": "fa00203A",
+            "currentColor": "ff00302F",
+            "lastOnColor": "f1e2d3e4",
+            "durationsMs": {"colorFade": 1000, "effectFade": 1500, "effectStep": 2000},
+            "favColors": {"0": "ff", "1": "00", "2": "c0", "3": "40", "4": "00"},
+            "effectsNames": {"0": "NONE", "1": "FADE", "2": "Stroboskop", "3": "BELL"},
+        }
+    }
+    DEVICE_EXTENDED_INFO_COLORMODE_3 = {
+        "rgbw": {
+            "colorMode": 3,
+            "effectID": 0,
+            "desiredColor": "fa00203A",
+            "currentColor": "ff00302F",
+            "lastOnColor": "f1e2d3e4",
+            "durationsMs": {"colorFade": 1000, "effectFade": 1500, "effectStep": 2000},
+            "favColors": {"0": "ff", "1": "00", "2": "c0", "3": "40", "4": "00"},
+            "effectsNames": {"0": "NONE", "1": "FADE", "2": "Stroboskop", "3": "BELL"},
+        }
+    }
+    DEVICE_EXTENDED_INFO_COLORMODE_4 = {
+        "rgbw": {
+            "colorMode": 4,
+            "effectID": 0,
+            "desiredColor": "fa00203A",
+            "currentColor": "ff00302F",
+            "lastOnColor": "f1e2d3e4",
+            "durationsMs": {"colorFade": 1000, "effectFade": 1500, "effectStep": 2000},
+            "favColors": {"0": "ff", "1": "00", "2": "c0", "3": "40", "4": "00"},
+            "effectsNames": {"0": "NONE", "1": "FADE", "2": "Stroboskop", "3": "BELL"},
+        }
+    }
+    DEVICE_EXTENDED_INFO_COLORMODE_5 = {
+        "rgbw": {
+            "colorMode": 5,
+            "effectID": 0,
+            "desiredColor": "fa00203A",
+            "currentColor": "ff00302F",
+            "lastOnColor": "f1e2d3e4",
+            "durationsMs": {"colorFade": 1000, "effectFade": 1500, "effectStep": 2000},
+            "favColors": {"0": "ff", "1": "00", "2": "c0", "3": "40", "4": "00"},
+            "effectsNames": {"0": "NONE", "1": "FADE", "2": "Stroboskop", "3": "BELL"},
+        }
+    }
+
+    DEVICE_EXTENDED_INFO_COLORMODE_6 = {
+        "rgbw": {
+            "colorMode": 6,
+            "effectID": 0,
+            "desiredColor": "fa00203A",
+            "currentColor": "ff00302F",
+            "lastOnColor": "f1e2d3e4",
+            "durationsMs": {"colorFade": 1000, "effectFade": 1500, "effectStep": 2000},
+            "favColors": {"0": "ff", "1": "00", "2": "c0", "3": "40", "4": "00"},
+            "effectsNames": {"0": "NONE", "1": "FADE", "2": "Stroboskop", "3": "BELL"},
+        }
+    }
+    DEVICE_EXTENDED_INFO_COLORMODE_7 = {
+        "rgbw": {
+            "colorMode": 7,
+            "effectID": 0,
+            "desiredColor": "fcfffcff00",
+            "currentColor": "fcfffcff00",
+            "lastOnColor": "fcfffcff00",
+            "durationsMs": {"colorFade": 1000, "effectFade": 1000, "effectStep": 1000},
+            "favColors": {"0": "ff", "1": "00", "2": "c0", "3": "40", "4": "00"},
+            "effectsNames": {"0": "NONE", "1": "FADE", "2": "Stroboskop", "3": "BELL"},
+        }
+    }
 
     def patch_version(apiLevel):
         """Generate a patch for a JSON state fixture."""
@@ -574,11 +761,10 @@ class TestWLightBox(DefaultBoxTest):
         {{ "device": {{ "apiLevel": {apiLevel} }} }}
         """
 
-    DEVICE_INFO_FUTURE = jmerge(DEVICE_INFO, patch_version(20190809))
-    DEVICE_INFO_LATEST = jmerge(DEVICE_INFO, patch_version(20190808))
-    DEVICE_INFO_OUTDATED = jmerge(DEVICE_INFO, patch_version(20190807))
-
-    DEVICE_INFO_MINIMUM = jmerge(DEVICE_INFO, patch_version(20180718))
+    DEVICE_INFO_FUTURE = jmerge(DEVICE_INFO, patch_version(future_date()))
+    DEVICE_INFO_LATEST = jmerge(
+        DEVICE_INFO, patch_version(get_latest_api_level("wLightBox"))
+    )
     DEVICE_INFO_UNSUPPORTED = jmerge(DEVICE_INFO, patch_version(20180717))
 
     DEVICE_INFO_UNSPECIFIED_API = json.loads(
@@ -614,8 +800,8 @@ class TestWLightBox(DefaultBoxTest):
         """
     {
       "rgbw": {
-        "colorMode": 1,
-        "effectId": 2,
+        "colorMode": 4,
+        "effectID": 0,
         "desiredColor": "fa00203A",
         "currentColor": "ff00302F",
         "lastOnColor": "f1e2d3e4",
@@ -666,15 +852,15 @@ class TestWLightBox(DefaultBoxTest):
         await self.allow_get_info(aioclient_mock)
         entity = (await self.async_entities(aioclient_mock))[0]
 
-        assert entity.name == "My light 1 (wLightBox#color)"
-        assert entity.unique_id == "BleBox-wLightBox-1afe34e750b8-color"
+        assert entity.name == "My light 1 (wLightBox#color_RGBorW)"
+        assert entity.unique_id == "BleBox-wLightBox-1afe34e750b8-color_RGBorW"
+        # In current state of master branch white_value is not property of BleBoxLightEntity, fake test... dissapointing
+        # assert entity.supported_features & SUPPORT_WHITE_VALUE
+        # assert entity.white_value is None
 
-        assert entity.supported_features & SUPPORT_WHITE_VALUE
-        assert entity.white_value is None
-
-        assert entity.supported_features & SUPPORT_COLOR
-        assert entity.hs_color is None
-        assert entity.white_value is None
+        # assert entity.supported_features & SUPPORT_COLOR
+        # assert entity.hs_color is None
+        # assert entity.white_value is None
 
         # assert entity.supported_features & SUPPORT_BRIGHTNESS
         # assert entity.brightness == 123
@@ -693,13 +879,14 @@ class TestWLightBox(DefaultBoxTest):
         """Test light updating."""
 
         entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
-        # assert entity.brightness == 123
-        assert entity.hs_color == (352.32, 100.0)
-        assert entity.white_value == 0x3A
+        assert entity.brightness == 250
+        # assert entity.hs_color == (352.32, 100.0)
+        # assert entity.white_value == 0x3A
         assert entity.is_on is True  # state already available
 
     async def allow_set_color(self, code, aioclient_mock, value, response):
         """Set up mock for HTTP POST simulating color change."""
+        print("allow_set_color", response)
         await self.allow_post(
             code,
             aioclient_mock,
@@ -708,80 +895,6 @@ class TestWLightBox(DefaultBoxTest):
             response,
         )
 
-    async def test_on_via_just_whiteness(self, aioclient_mock):
-        """Test light on."""
-        entity = await self.updated(aioclient_mock, self.STATE_OFF)
-        assert entity.is_on is False
-
-        async def action():
-            await entity.async_turn_on(**{ATTR_WHITE_VALUE: 0xC7})
-
-        await self.allow_set_color(
-            action, aioclient_mock, "f1e2d3c7", self.STATE_ON_AFTER_WHITE
-        )
-
-        assert entity.is_on is True
-        assert entity.white_value == 0xC7
-        assert entity.hs_color == color_RGB_to_hs(0xF1, 0xE2, 0xD3)
-
-    async def test_on_via_reset_whiteness(self, aioclient_mock):
-        """Test light on."""
-        entity = await self.updated(aioclient_mock, self.STATE_OFF)
-        assert entity.is_on is False
-
-        async def action():
-            await entity.async_turn_on(**{ATTR_WHITE_VALUE: 0x0})
-
-        await self.allow_set_color(
-            action, aioclient_mock, "f1e2d300", self.STATE_ON_AFTER_RESET_WHITE
-        )
-
-        assert entity.is_on is True
-        assert entity.white_value == 0x0
-        assert entity.hs_color == color_RGB_to_hs(0xF1, 0xE2, 0xD3)
-
-    async def test_on_via_just_hsl_color_with_last(self, aioclient_mock):
-        """Test light on."""
-
-        # last color: "f1e2d3e4"
-
-        entity = await self.updated(aioclient_mock, self.STATE_OFF)
-        assert entity.is_on is False
-
-        input_rgb = (0xFF, 0xA1, 0xB2)
-        hs_color = color_RGB_to_hs(*input_rgb)
-
-        async def action():
-            await entity.async_turn_on(**{ATTR_HS_COLOR: hs_color})
-
-        response = self.STATE_AFTER_SOME_COLOR_SET
-        await self.allow_set_color(action, aioclient_mock, "ffa0b1e4", response)
-
-        # TODO: second part of test not needed
-        assert entity.is_on is True
-        assert entity.hs_color == color_RGB_to_hs(*input_rgb)
-        assert entity.white_value == 0xE4
-
-    async def test_on_via_just_hsl_color_with_no_white(self, aioclient_mock):
-        """Test light on."""
-
-        entity = await self.updated(aioclient_mock, self.STATE_OFF_NOLAST_WHITE)
-        assert entity.is_on is False
-
-        input_rgb = (0xFF, 0xA1, 0xB2)
-        hs_color = color_RGB_to_hs(*input_rgb)
-
-        async def action():
-            await entity.async_turn_on(**{ATTR_HS_COLOR: hs_color})
-
-        response = self.STATE_ON_ONLY_SOME_COLOR
-        await self.allow_set_color(action, aioclient_mock, "ffa0b100", response)
-
-        # TODO: second part of test not needed
-        assert entity.is_on is True
-        assert entity.hs_color == color_RGB_to_hs(*input_rgb)
-        assert entity.white_value == 0x0
-
     async def test_on_to_last_color(self, aioclient_mock):
         """Test light on."""
         entity = await self.updated(aioclient_mock, self.STATE_OFF)
@@ -795,8 +908,10 @@ class TestWLightBox(DefaultBoxTest):
         )
 
         assert entity.is_on is True
-        assert entity.white_value == 0xE4
-        assert entity.hs_color == color_RGB_to_hs(0xF1, 0xE2, 0xD3)
+        # assert entity.white_value == 0xE4
+        assert entity.rgbw_color == tuple(
+            [int(i, 16) for i in ["f1", "e2", "d3", "e4"]]
+        )
 
     async def test_off(self, aioclient_mock):
         """Test light off."""
@@ -809,8 +924,7 @@ class TestWLightBox(DefaultBoxTest):
         await self.allow_set_color(action, aioclient_mock, "00000000", self.STATE_OFF)
 
         assert entity.is_on is False
-        assert entity.hs_color == (0, 0)
-        assert entity.white_value == 0x00
+        # assert entity.white_value == 0x00
 
     async def test_ancient_response(self, aioclient_mock):
         """Test e.g. unsupported, ancient device status structure."""
@@ -830,5 +944,237 @@ class TestWLightBox(DefaultBoxTest):
         )
 
         await self.allow_get_info(aioclient_mock, DEVICE_INFO_ANCIENT_STRUCTURE)
-        with pytest.raises(UnsupportedBoxResponse):
+        with pytest.raises(UnsupportedBoxVersion):
             await self.async_entities(aioclient_mock)
+
+    """
+        1. ustawic setup mocka do inicjalizacji obiektu
+        2. dostep do encji
+        3. asercje
+    """
+
+    async def test_colormode_5_brightness(self, aioclient_mock):
+        self.DEVICE_EXTENDED_INFO = self.DEVICE_EXTENDED_INFO_COLORMODE_5
+        await self.allow_get_info(aioclient_mock)
+        self.STATE_DEFAULT["colorMode"] = 5
+        entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
+
+        assert "_cct" in entity.name
+        assert entity.brightness == 250
+
+    async def test_colormode_6_brightness(self, aioclient_mock):
+        self.DEVICE_EXTENDED_INFO = self.DEVICE_EXTENDED_INFO_COLORMODE_6
+        await self.allow_get_info(aioclient_mock)
+        self.STATE_DEFAULT["colorMode"] = 6
+        entity = await self.updated(aioclient_mock, self.STATE_DEFAULT, 1)
+
+        assert "_cct2" in entity.name
+        assert entity.brightness
+
+    async def test_many_from_config_check_empty(self, aioclient_mock):
+        pass
+
+    async def test_effect_list_return_list(self, aioclient_mock):
+        self.DEVICE_EXTENDED_INFO = self.DEVICE_EXTENDED_INFO_COLORMODE_5
+        await self.allow_get_info(aioclient_mock)
+        self.STATE_DEFAULT["colorMode"] = 5
+        entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
+
+        assert entity.effect_list
+
+    async def test_color_temp_for_colomode_6(self, aioclient_mock):
+        self.DEVICE_EXTENDED_INFO = self.DEVICE_EXTENDED_INFO_COLORMODE_6
+        await self.allow_get_info(aioclient_mock)
+        self.STATE_DEFAULT["colorMode"] = 6
+        entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
+
+        assert "_cct1" in entity.name
+        assert entity.color_temp
+
+    async def test_color_temp_for_colomode_rgbww(self, aioclient_mock):
+        self.DEVICE_EXTENDED_INFO = self.DEVICE_EXTENDED_INFO_COLORMODE_7
+        await self.allow_get_info(aioclient_mock)
+        self.STATE_DEFAULT["colorMode"] = 7
+        entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
+
+        assert "_RGBCCT" in entity.name
+        assert entity.color_temp
+        assert entity.brightness
+
+    async def test_normalise_element_colormode_rgb(self, aioclient_mock):
+        # testing sensible on value which is used only while async_turn_on executed
+
+        self.DEVICE_EXTENDED_INFO = self.DEVICE_EXTENDED_INFO_COLORMODE_2
+        self.DEVICE_EXTENDED_INFO = jmerge(
+            self.DEVICE_EXTENDED_INFO, self.patch_state("fafafa", "fafafa")
+        )
+        self.STATE_DEFAULT["rgbw"]["colorMode"] = 2
+
+        self.STATE_DEFAULT = jmerge(
+            self.STATE_DEFAULT, self.patch_state("fafafa", "fafafa")
+        )
+
+        await self.allow_get_info(aioclient_mock)
+        print("INTEST:\n", self.DEVICE_EXTENDED_INFO, "\nEntity:\n")
+        entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
+
+        async def turn_on():
+            await entity.async_turn_on(rgb_color=(255, 0, 140))
+
+        self.STATE_ON = jmerge(self.STATE_ON, self.patch_state("fafafa", "fafafa"))
+        await self.allow_set_color(turn_on, aioclient_mock, "fa0089", self.STATE_ON)
+
+        assert max(entity.rgbw_color) == 250
+
+    async def test_normalise_when_max_is_zero_rgb(self, aioclient_mock):
+        # testing sensible on value which is used only while async_turn_on executed
+
+        self.DEVICE_EXTENDED_INFO = self.DEVICE_EXTENDED_INFO_COLORMODE_2
+        self.DEVICE_EXTENDED_INFO = jmerge(
+            self.DEVICE_EXTENDED_INFO, self.patch_state("030303", "030303")
+        )
+        self.STATE_DEFAULT["rgbw"]["colorMode"] = 2
+
+        self.STATE_DEFAULT = jmerge(
+            self.STATE_DEFAULT, self.patch_state("030303", "030303")
+        )
+
+        await self.allow_get_info(aioclient_mock)
+        print("INTEST:\n", self.DEVICE_EXTENDED_INFO, "\nEntity:\n")
+        entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
+
+        async def turn_on():
+            await entity.async_turn_on(rgb_color=(255, 10, 255))
+
+        self.STATE_ON = jmerge(self.STATE_ON, self.patch_state("000000", "000000"))
+        await self.allow_set_color(turn_on, aioclient_mock, "030003", self.STATE_ON)
+
+        assert max(entity.rgb_color) == 255
+
+    async def test_sensible_on_value_for_color_mode_1(self, aioclient_mock):
+
+        self.DEVICE_EXTENDED_INFO = self.DEVICE_EXTENDED_INFO_COLORMODE_1
+        self.DEVICE_EXTENDED_INFO = jmerge(
+            self.DEVICE_EXTENDED_INFO, self.patch_state("00000000", "00000000")
+        )
+        self.STATE_DEFAULT["rgbw"]["colorMode"] = 1
+
+        self.STATE_DEFAULT = jmerge(
+            self.STATE_DEFAULT, self.patch_state("00000000", "00000000")
+        )
+
+        await self.allow_get_info(aioclient_mock)
+
+        entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
+
+        async def turn_on():
+            await entity.async_turn_on()
+
+        self.STATE_ON = jmerge(self.STATE_ON, self.patch_state("ffffffff", "ffffffff"))
+        await self.allow_set_color(turn_on, aioclient_mock, "ffffffff", self.STATE_ON)
+
+        assert entity.rgbw_color == (255, 255, 255, 255)
+
+    async def test_sensible_on_value_for_color_mode_5(self, aioclient_mock):
+        self.DEVICE_EXTENDED_INFO = self.DEVICE_EXTENDED_INFO_COLORMODE_5
+        self.DEVICE_EXTENDED_INFO = jmerge(
+            self.DEVICE_EXTENDED_INFO, self.patch_state("00000000", "00000000")
+        )
+        self.STATE_DEFAULT["rgbw"]["colorMode"] = 5
+
+        self.STATE_DEFAULT = jmerge(
+            self.STATE_DEFAULT, self.patch_state("00000000", "00000000")
+        )
+
+        await self.allow_get_info(aioclient_mock)
+        self.STATE_DEFAULT["colorMode"] = 5
+        entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
+
+        print("INTEST:\n", entity.name, "\nEntity:\n")
+
+        async def turn_on():
+            await entity.async_turn_on()
+
+        self.STATE_ON = jmerge(self.STATE_ON, self.patch_state("ffffffff", "ffffffff"))
+        await self.allow_set_color(turn_on, aioclient_mock, "ffff------", self.STATE_ON)
+
+        assert entity.color_temp == 128
+
+    async def test_turn_on_color_temp_full_warm_for_color_mode_5(self, aioclient_mock):
+        self.DEVICE_EXTENDED_INFO = self.DEVICE_EXTENDED_INFO_COLORMODE_5
+        self.STATE_DEFAULT["rgbw"]["colorMode"] = 5
+
+        await self.allow_get_info(aioclient_mock)
+        self.STATE_DEFAULT["colorMode"] = 5
+        entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
+
+        print("INTEST:\n", entity.name, "\nEntity:\n")
+
+        async def turn_on():
+            await entity.async_turn_on(color_temp=1)
+
+        self.STATE_ON = jmerge(self.STATE_ON, self.patch_state("02ffffff", "02ffffff"))
+
+        await self.allow_set_color(turn_on, aioclient_mock, "02fa------", self.STATE_ON)
+
+        assert entity.color_temp == 1
+
+    async def test_turn_on_color_temp_full_cold_for_color_mode_5(self, aioclient_mock):
+        self.DEVICE_EXTENDED_INFO = self.DEVICE_EXTENDED_INFO_COLORMODE_5
+        self.STATE_DEFAULT["rgbw"]["colorMode"] = 5
+
+        await self.allow_get_info(aioclient_mock)
+        self.STATE_DEFAULT["colorMode"] = 5
+        entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
+
+        async def turn_on():
+            await entity.async_turn_on(color_temp=255)
+
+        self.STATE_ON = jmerge(self.STATE_ON, self.patch_state("fa00ffff", "fa02ffff"))
+
+        await self.allow_set_color(turn_on, aioclient_mock, "fa00------", self.STATE_ON)
+
+        assert entity.color_temp == 255
+
+    async def test_sensible_on_value_for_color_mode_6(self, aioclient_mock):
+        self.DEVICE_EXTENDED_INFO = self.DEVICE_EXTENDED_INFO_COLORMODE_6
+        self.STATE_DEFAULT["rgbw"]["colorMode"] = 6
+
+        await self.allow_get_info(aioclient_mock)
+        self.STATE_DEFAULT["colorMode"] = 6
+        entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
+
+        async def turn_on():
+            await entity.async_turn_on(color_temp=255)
+
+        self.STATE_ON = jmerge(self.STATE_ON, self.patch_state("fa00ffff", "fa02ffff"))
+
+        await self.allow_set_color(turn_on, aioclient_mock, "fa00------", self.STATE_ON)
+
+        assert entity.color_temp == 255
+
+    async def test_sensible_on_value_for_color_mode_7(self, aioclient_mock):
+        self.DEVICE_EXTENDED_INFO = self.DEVICE_EXTENDED_INFO_COLORMODE_7
+        self.STATE_DEFAULT["rgbw"]["colorMode"] = 7
+        self.STATE_DEFAULT = jmerge(
+            self.STATE_DEFAULT, self.patch_state("fcfffcff00", "fcfffcff00")
+        )
+        await self.allow_get_info(aioclient_mock)
+        self.STATE_DEFAULT["colorMode"] = 7
+        entity = await self.updated(aioclient_mock, self.STATE_DEFAULT)
+
+        async def turn_on():
+            await entity.async_turn_on(rgbww_color=(0, 0, 0, 120, 214))
+
+        self.STATE_ON = jmerge(
+            self.STATE_ON, self.patch_state("000000d678", "000000d678")
+        )
+
+        await self.allow_set_color(turn_on, aioclient_mock, "000000d678", self.STATE_ON)
+
+        assert entity.rgbww_color == (0, 0, 0, 120, 214)
+
+
+def test_unit_light_evaluate_brightness_from_rgb():
+    tested_ob = Light.evaluate_brightness_from_rgb(iterable=(140, 230))
+    assert tested_ob == 230
